/**
 * This program has been developed by students from the bachelor Computer Science at
 * Utrecht University within the Software Project course.
 * © Copyright Utrecht University (Department of Information and Computing Sciences)
 */

import { Position } from 'reactflow';
import { GeneralDescription, InputNode, NumberFilterTypes } from './general';

export const MathFilters: Record<NumberFilterTypes, GeneralDescription<NumberFilterTypes>> = {
  [NumberFilterTypes.EQUAL]: {
    key: 'numberFilterEqual',
    name: 'Equal',
    type: NumberFilterTypes.EQUAL,
    description: 'Equal to another value',
    numInputs: 2,
    inputs: [
      { name: '1', type: 'float', default: 0 },
      { name: '2', type: 'float', default: 0 },
    ],
    output: { name: '==', type: 'float' },
    logic: ['==', '@1', '@2'],
    icon: '=',
  },
  [NumberFilterTypes.NOT_EQUAL]: {
    key: 'numberFilterNotEqual',
    name: 'Not Equal',
    type: NumberFilterTypes.NOT_EQUAL,
    description: 'Not equal to another value',
    numInputs: 2,
    inputs: [
      { name: '1', type: 'float', default: 0 },
      { name: '2', type: 'float', default: 0 },
    ],
    output: { name: '!=', type: 'float' },
    logic: ['!=', '@1', '@2'],
    icon: '≠',
  },
  [NumberFilterTypes.LESS_THAN]: {
    key: 'numberFilterLessThan',
    name: 'Less Than',
    type: NumberFilterTypes.LESS_THAN,
    description: 'Less than another value',
    numInputs: 2,
    inputs: [
      { name: '1', type: 'float', default: 0 },
      { name: '2', type: 'float', default: 0 },
    ],
    output: { name: '<', type: 'float' },
    logic: ['<', '@1', '@2'],
    icon: '<',
  },
  [NumberFilterTypes.LESS_THAN_EQUAL]: {
    key: 'numberFilterLessThanOrEqual',
    name: 'Less Than or Equal',
    type: NumberFilterTypes.LESS_THAN_EQUAL,
    description: 'Less than or equal to another value',
    numInputs: 2,
    inputs: [
      { name: '1', type: 'float', default: 0 },
      { name: '2', type: 'float', default: 0 },
    ],
    output: { name: '<=', type: 'float' },
    logic: ['<=', '@1', '@2'],
    icon: '≤',
  },
  [NumberFilterTypes.GREATER_THAN]: {
    key: 'numberFilterGreaterThan',
    name: 'Greater Than',
    type: NumberFilterTypes.GREATER_THAN,
    description: 'Greater than another value',

    numInputs: 2,
    inputs: [
      { name: '1', type: 'float', default: 0 },
      { name: '2', type: 'float', default: 0 },
    ],
    output: { name: '>', type: 'float' },
    logic: ['>', '@1', '@2'],
    icon: '>',
  },
  [NumberFilterTypes.GREATER_THAN_EQUAL]: {
    key: 'numberFilterGreaterThanOrEqual',
    name: 'Greater Than or Equal',
    type: NumberFilterTypes.GREATER_THAN_EQUAL,
    description: 'Greater than or equal to another value',
    numInputs: 2,
    inputs: [
      { name: '1', type: 'float', default: 0 },
      { name: '2', type: 'float', default: 0 },
    ],
    output: { name: '>=', type: 'float' },
    logic: ['>=', '@1', '@2'],
    icon: '≥',
  },
};

/** All available functions in the function bar. */
export const MathFilterArray: Array<GeneralDescription<NumberFilterTypes>> = Object.values(MathFilters);
